@@ -312,13 +312,17 @@ def run_import(address, id, verbose, dry_run, working_dir, no_lock, terragrunt_a
     help='Show output as json',
     show_default=True
     )
+@click.option('--terrasafe-config', '-T', default=None,
+    help='Name of the terrasafe config file (or set the TERRASAFE_CONFIG environment variable)',
+    envvar='TERRASAFE_CONFIG', type=click.Path(),
+    )
 @click.option('--parallel-execution', '-p', is_flag=True, default=False,
     help='Whether or not to use parallel execution',
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
 def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, 
-    start_at_step, out, parallel_execution, terragrunt_args):
+    start_at_step, out, parallel_execution, terrasafe_config, terragrunt_args):
     """ Analyzes the plan files """
 
     check_latest_version(verbose)
@@ -331,6 +335,7 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir,
         start_at_step=start_at_step,
         out=out,
         parallel_execution=parallel_execution,
+        terrasafe_config=terrasafe_config,
         terragrunt_args=terragrunt_args,
     )
 
@@ -340,13 +345,6 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir,
         ignore_unknown_options=True,
     ),
 )
-@click.option('--domain', '-d', required=True,
-    help='Domain that needs to be locked',
-    )
-@click.option('--stage', '-s', required=True,
-    type=click.Choice(STAGES, case_sensitive=True),
-    help='Stage that needs to be unlocked.',
-    )
 @click.option('--module', '-m', required=True,
     help='Name of the lockiung module (or set LOCK_MODULE environment variable)',
     envvar='LOCK_MODULE'
@@ -364,18 +362,16 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir,
     show_default=True
     )
 @click.option('--working-dir', '-w', default=None,
-    help='Working directory, when omitted the current directory is used',
+    help='Working directory, when omitted the current directory is assumed to be your stage is the target',
     )
 @click.version_option(version=__version__)
-def lock(domain, stage, module, auto_approve, verbose, dry_run, working_dir):
-    """ Lock a particular domain/stage """
+def lock(module, auto_approve, verbose, dry_run, working_dir):
+    """ Lock a particular stage """
 
     check_latest_version(verbose)
 
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.set_lock(
-        domain=domain,
-        stage=stage,
         module=module,
         lock_status="lock",
         auto_approve=auto_approve,
@@ -389,13 +385,6 @@ def lock(domain, stage, module, auto_approve, verbose, dry_run, working_dir):
         ignore_unknown_options=True,
     ),
 )
-@click.option('--domain', '-d', required=True,
-    help='Domain that needs to be locked',
-    )
-@click.option('--stage', '-s', required=True,
-    type=click.Choice(STAGES, case_sensitive=True),
-    help='Stage that needs to be unlocked.',
-    )
 @click.option('--module', '-m', required=True,
     help='Name of the lockiung module (or set LOCK_MODULE environment variable)',
     envvar='LOCK_MODULE'
@@ -413,18 +402,16 @@ def lock(domain, stage, module, auto_approve, verbose, dry_run, working_dir):
     show_default=True
     )
 @click.option('--working-dir', '-w', default=None,
-    help='Working directory, when omitted the current directory is used',
+    help='Working directory, when omitted the current directory is assumed to be your stage is the target',
     )
 @click.version_option(version=__version__)
-def unlock(domain, stage, module, auto_approve, verbose, dry_run, working_dir):
-    """ Unlock a particular domain/stage """
+def unlock(module, auto_approve, verbose, dry_run, working_dir):
+    """ Unlock a particular stage """
 
     check_latest_version(verbose)
 
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.set_lock(
-        domain=domain,
-        stage=stage,
         module=module,
         lock_status="unlock",
         auto_approve=auto_approve,
