@@ -611,7 +611,7 @@ class TgWrap():
             self.printer.verbose(rc)
 
     def analyze(self, dry_run, exclude_external_dependencies, working_dir,
-        start_at_step, out, parallel_execution, terragrunt_args):
+        start_at_step, out, parallel_execution, terrasafe_config, terragrunt_args):
         """ Analyzes the plan files """
 
         self.printer.verbose("Attempting to 'analyze'")
@@ -626,26 +626,18 @@ class TgWrap():
             terragrunt_args=terragrunt_args,
             )
 
-        # Check if the "TERRASAFE_CONFIG" environment variable is set
-        env_var = "TERRASAFE_CONFIG"
         ts_config = None
-        if not env_var in os.environ:
+        if not terrasafe_config:
             self.printer.warning(
-                f"{env_var} environment variable is not set, this is required for running the terrasafe command!"
-                )
-        # and if it exists as a file
-        elif not os.path.exists(os.environ.get(env_var)):
-            self.printer.warning(
-                f"{env_var} environment variable is set, but the file it points to does not exist!"
+                f"Terrasafe config file is not set, this is required for running the terrasafe command!"
                 )
         else:
-            config_path = os.environ.get(env_var)
             self.printer.verbose(
-                f"\nRun terrasafe using config {config_path}"
+                f"\nRun terrasafe using config {terrasafe_config}"
                 )
 
-            config_file = open(config_path)
-            ts_config = json.load(config_file)
+            with open(terrasafe_config) as f:
+                ts_config = json.load(f)
 
         ts_validation_successful = True
         changes = {}
@@ -712,7 +704,7 @@ class TgWrap():
                             self.printer.warning(f'Planfile for module {module} is empty')
                     except json.decoder.JSONDecodeError as e:
                         raise Exception(
-                            f"Planfile for {module} was no proper json, further analysis not possible."
+                            f"Planfile for {module} was not proper json, further analysis not possible:\n{plan_file[:100]}"
                             ) from e
         finally:
             os.remove(f.name)
@@ -742,12 +734,12 @@ class TgWrap():
             self.printer.error("Terrasafe validation failed on one or more modules")
             sys.exit(1)
 
-    def set_lock(self, domain, stage, module, lock_status, auto_approve, dry_run, working_dir):
-        """ Set the lock status of a particular domain/stage """
+    def set_lock(self, module, lock_status, auto_approve, dry_run, working_dir):
+        """ Set the lock status of the stage you're in """
     
         # do we have a working dir?
         working_dir = working_dir if working_dir else os.getcwd()
-        module_path = os.path.join(working_dir, domain, stage, module)
+        module_path = os.path.join(working_dir, module)
 
         command = "destroy" if lock_status == "unlock" else "apply" 
 
